Module: enums.py — badsnakes - v0.2.0 Documentation

# Module: enums.py

Purpose:

  This module provides the various enumerators to the project.

Platform:

  Linux/Windows | Python 3.10+

Developer:

  J Berendt

Email:

  development@s3dev.uk

Comments:

  n/a

Example:

  Import the `Severity` enumerator into a module:

      >>> from badsnakes.libs.enums import Severity

class badsnakes.libs.enums.ExCode(value, names=<not given>, *values, module=None, qualname=None, type=None, start=1, boundary=None)

  Bases: `IntEnum`

  Exit code enumerator class.

class badsnakes.libs.enums.Severity(value, names=<not given>, *values, module=None, qualname=None, type=None, start=1, boundary=None)

  Bases: `IntEnum`

  Statement severity enumerator class.